@@ -1,9 +1,9 @@
 #pragma once
 #define GVPLUGIN_CONFIG_FILE "config6"
 #define GVPLUGIN_VERSION 6
-#define PACKAGE_BUGREPORT "http://www.graphviz.org/"
+#define PACKAGE_BUGREPORT "https://gitlab.com/graphviz/graphviz/-/issues"
 #define PACKAGE_NAME "graphviz"
-#define PACKAGE_STRING "graphviz 2.46.1"
+#define PACKAGE_STRING "graphviz 7.0.0"
 #define PACKAGE_TARNAME "graphviz"
 #define PACKAGE_URL ""
-#define PACKAGE_VERSION "2.46.1"
+#define PACKAGE_VERSION "7.0.0"
